@@ -157,7 +157,7 @@ db_reconnect.chMDB <- function(x, user, password, ntries=3, ...){
    xn <- deparse(substitute(x))
    x <- unclass(x)
    tkcon <- x$tkcon
-   db_reconnect(tkcon, user=user, password=password, ntries=ntries)
+   db_reconnect(tkcon, user=user, password=password, ntries=ntries, ...)
    nv <- x
    nv$tkcon <- tkcon
    class(nv) <- c("chMDB", "MDB", class(nv))
@@ -468,8 +468,10 @@ as_chMDB <- function(x, tkcon, timestamp=Sys.time(), overwrite=FALSE, by=10^5){
    ## Rules of update ----
    tst <- list_chMDB_timestamps(tkcon, dbName)
    maxTs <- suppressWarnings(max(tst$timestamp))
-   if(!is.na(timestamp) && !is.null(maxTs) && timestamp <= maxTs){
-      stop("Timestamp should be more recent than those already recorded")
+   if(!is.na(timestamp) && !is.null(maxTs) && timestamp - maxTs <= 60){
+      stop(
+         "Timestamp should be more recent (60 sec.) than those already recorded"
+      )
    }
    makeEmpty <- makeArchive <- setTS <- FALSE
    if(!dbName %in% mdbl$name[which(mdbl$populated)]){
@@ -1008,20 +1010,111 @@ dims.chMDB <- function(x, ...){
    }
    toTake <- names(toTake)
    dbt <- db_tables(x)
-   toTake <- dbt$dbTables[toTake]
    m <- data_model(x)
    
-   toRet <- do.call(dplyr::bind_rows, lapply(
-      names(toTake),
-      function(tn){
-         .dim_ch_mtable(
-            x,
-            tablePath=toTake[tn], tableModel=m[[tn]]
+   dbTables <- list_tables(unclass(x)$tkcon, db_info(x)$name) %>% 
+      dplyr::mutate(
+         "instance"=paste0("`", .data$database, "`.`", .data$name, "`")
+      )
+   matrices <- lapply(m, ReDaMoR::is.MatrixModel) %>%
+      unlist() %>% which() %>% names()
+   
+   tables <- setdiff(names(m), matrices)
+   if(length(tables)==0){
+      tableValues <- NULL
+   }else{
+      tableValues <- dplyr::tibble(
+         table=tables,
+         instance=as.character(dbt$dbTables[tables])
+      ) %>% 
+         dplyr::left_join(
+            dbTables %>% 
+               dplyr::select(
+                  "instance",
+                  "total_rows", "total_bytes", "total_columns",
+                  "transposed"
+               ),
+            by="instance"
+         ) %>% 
+         dplyr::mutate(format="table") %>% 
+         dplyr::select(
+            "name"="table", "format",
+            "ncol"="total_columns",
+            "nrow"="total_rows",
+            "records"="total_rows",
+            "bytes"="total_bytes",
+            "transposed"
          )
+   }
+   
+   if(length(matrices)==0){
+      matValues <- NULL
+   }else{
+      matTables <- get_query(
+         x,
+         paste(
+            sprintf(
+               "SELECT *, '%s' as matrice from %s",
+               matrices, dbt$dbTables[matrices]
+            ),
+            collapse=" UNION ALL "
+         )
+      )
+      if(!"info" %in% colnames(matTables)){
+         matTables$info <- "values"
       }
-   )) %>%
-      dplyr::mutate(name=names(toTake)) %>% 
-      dplyr::relocate("name")
+      matValues <- matTables %>%
+         dplyr::left_join(dbTables, by=c("table"="name")) %>%
+         dplyr::group_by(.data$matrice) %>% 
+         dplyr::summarize(
+            transposed=.data$transposed[1],
+            format=if(all(.data$info=="values")){
+               "matrix"
+            }else{
+               "MatrixMarket"
+            },
+            nrow=if(all(.data$info=="values")){
+               if(.data$transposed[1]){
+                  sum(.data$total_columns)
+               }else{
+                  .data$total_rows[1]
+               }
+            }else{
+               .data$total_rows[which(.data$info=="rows")]
+            },
+            ncol=if(all(.data$info=="values")){
+               if(.data$transposed[1]){
+                  .data$total_rows[1]
+               }else{
+                  sum(.data$total_columns)
+               }
+            }else{
+               .data$total_rows[which(.data$info=="columns")]
+            },
+            bytes=sum(.data$total_bytes)
+         ) %>% 
+         dplyr::mutate(records=.data$nrow*.data$ncol) %>% 
+         dplyr::select(
+            "name"="matrice",
+            "format", "ncol", "nrow", "records", "bytes", "transposed"
+         )
+   }
+   
+   toRet <- rbind(tableValues, matValues) %>% 
+      dplyr::slice(match(toTake, .data$name))
+   
+   
+   # toRet <- do.call(dplyr::bind_rows, lapply(
+   #    names(toTake),
+   #    function(tn){
+   #       .dim_ch_mtable(
+   #          x,
+   #          tablePath=toTake[tn], tableModel=m[[tn]]
+   #       )
+   #    }
+   # )) %>%
+   #    dplyr::mutate(name=names(toTake)) %>% 
+   #    dplyr::relocate("name")
    
    return(toRet)
    
@@ -1254,22 +1347,24 @@ as_fileMDB.chMDB <- function(
          )
          
          rquery <- sprintf(
-            "SELECT i, name FROM %s ORDER BY i",
+            "SELECT i, name FROM %s",# ORDER BY i",
             sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="rows")])
          )
          rowNames <- get_query(
             x, rquery, autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$i)
          
          cquery <- sprintf(
-            "SELECT j, name FROM %s ORDER BY j",
+            "SELECT j, name FROM %s",# ORDER BY j",
             sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="columns")])
          )
          colNames <- get_query(
             x, cquery, autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$j)
          
          chTables <- list_tables(
             unclass(x)$tkcon$chcon, dbNames=tdb
@@ -1295,7 +1390,7 @@ as_fileMDB.chMDB <- function(
          )
          
          vtquery <- sprintf(
-            "SELECT i, j, x FROM %s ORDER BY j, i",
+            "SELECT i, j, x FROM %s",# ORDER BY j, i",
             sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="values")])
          )
          r <- 0
@@ -1306,7 +1401,8 @@ as_fileMDB.chMDB <- function(
          toWrite <- get_query(
             x, vquery, autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$j, .data$i)
          while(!is.null(toWrite) && nrow(toWrite)>0){
             readr::write_delim(
                toWrite, file=dfiles[tn],
@@ -1324,7 +1420,8 @@ as_fileMDB.chMDB <- function(
             toWrite <- get_query(
                x, vquery, autoalias=FALSE,
                format="Arrow"
-            )
+            ) %>% 
+               dplyr::arrange(.data$j, .data$i)
          }
 
       }else{
@@ -1587,14 +1684,15 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
                   x,
                   sprintf(
                      paste(
-                        "SELECT i, name FROM `%s`.`%s` WHERE name in ('%s')",
-                        "ORDER BY i"
+                        "SELECT i, name FROM `%s`.`%s` WHERE name in ('%s')"#,
+                        # "ORDER BY i"
                      ),
                      dbn, rt, paste(frn, collapse="', '")
                   ),
                   autoalias=FALSE,
                   format="Arrow"
-               )
+               ) %>% 
+                  dplyr::arrange(.data$i)
             }
          }
          if(ft=="column"){
@@ -1606,14 +1704,15 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
                   x,
                   sprintf(
                      paste(
-                        "SELECT j, name FROM `%s`.`%s` WHERE name in ('%s')",
-                        "ORDER BY j"
+                        "SELECT j, name FROM `%s`.`%s` WHERE name in ('%s')"#,
+                        # "ORDER BY j"
                      ),
                      dbn, ct, paste(fcn, collapse="', '")
                   ),
                   autoalias=FALSE,
                   format="Arrow"
-               )
+               ) %>% 
+                  dplyr::arrange(.data$j)
             }
          }
       }
@@ -1622,12 +1721,13 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
          fri <- get_query(
             x,
             sprintf(
-               "SELECT i, name FROM `%s`.`%s` ORDER BY i",
+               "SELECT i, name FROM `%s`.`%s`",# ORDER BY i",
                dbn, rt
             ),
             autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$i)
          frn <- fri$name
       }else(
          fri <- fr
@@ -1636,12 +1736,13 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
          fcj <- get_query(
             x,
             sprintf(
-               "SELECT j, name FROM `%s`.`%s` ORDER BY j",
+               "SELECT j, name FROM `%s`.`%s`",# ORDER BY j",
                dbn, ct
             ),
             autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$j)
          fcn <- fcj$name
       }else{
          fcj <- fc
@@ -1674,7 +1775,7 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
       
       ### Value query ----
       query <- sprintf(
-         "SELECT i, j, x FROM `%s`.`%s` WHERE %s AND %s ORDER BY j, i",
+         "SELECT i, j, x FROM `%s`.`%s` WHERE %s AND %s",# ORDER BY j, i",
          dbn, vt,
          ifelse(
             is.null(fr), "1",
@@ -1685,7 +1786,8 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
             sprintf('j in (%s)', paste(fc$j, collapse=", "))
          )
       )
-      toRet <- get_query(x, query, autoalias=FALSE, format="Arrow")
+      toRet <- get_query(x, query, autoalias=FALSE, format="Arrow") %>% 
+         dplyr::arrange(.data$j, .data$i)
       mi <- max(fri$i)
       mj <- max(fcj$j)
       if(!mi %in% toRet$i || !mj %in% toRet$j){
@@ -1874,6 +1976,9 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
       if(!vtype %in% c("Date", "POSIXct")){
          toRet <- toRet %>% magrittr::set_class(vtype)
       }
+      if(dimcol=="___COLNAMES___"){
+         toRet <- t(toRet)
+      }
       if(frc=="r"){
          toRet <- toRet[intersect(fr, rownames(toRet)),, drop=FALSE]
       }
@@ -1918,22 +2023,24 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
             
             ## Columns and rows
             rquery <- sprintf(
-               "SELECT i, name FROM %s ORDER BY i",
+               "SELECT i, name FROM %s",# ORDER BY i",
                sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="rows")])
             )
             rowNames <- get_query(
                x, rquery, autoalias=FALSE,
                format="Arrow"
-            )
+            ) %>% 
+               dplyr::arrange(.data$i)
             
             cquery <- sprintf(
-               "SELECT j, name FROM %s ORDER BY j",
+               "SELECT j, name FROM %s",# ORDER BY j",
                sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="columns")])
             )
             colNames <- get_query(
                x, cquery, autoalias=FALSE,
                format="Arrow"
-            )
+            ) %>% 
+               dplyr::arrange(.data$j)
             
             write_MergeTree(
                con=con,
@@ -1980,7 +2087,7 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
                dplyr::pull("total_rows")
             
             vtquery <- sprintf(
-               "SELECT i, j, x FROM %s ORDER BY j, i",
+               "SELECT i, j, x FROM %s",# ORDER BY j, i",
                sprintf('`%s`.`%s`', tdb, valTable)
             )
             r <- 0
@@ -1991,7 +2098,8 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
             toWrite <- get_query(
                x, vquery, autoalias=FALSE,
                format="Arrow"
-            )
+            ) %>% 
+               dplyr::arrange(.data$j, .data$i)
             while(!is.null(toWrite) && nrow(toWrite)>0){
                ch_insert(
                   con=con, dbName=dbName, tableName=valTable, value=toWrite
@@ -2005,7 +2113,8 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
                toWrite <- get_query(
                   x, vquery, autoalias=FALSE,
                   format="Arrow"
-               )
+               ) %>% 
+                  dplyr::arrange(.data$j, .data$i)
             }
             
             ## Reference table
@@ -2135,7 +2244,7 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
          }
          
          vquery <- sprintf(
-            "SELECT i, j, x FROM %s ORDER BY j, i",
+            "SELECT i, j, x FROM %s",# ORDER BY j, i",
             sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="values")])
          )
          vquery <- paste(
@@ -2145,29 +2254,32 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
          values <- get_query(
             x, vquery, autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$j, .data$i)
          
          rToTake <- max(values$i)
          rquery <- sprintf(
-            "SELECT i, name FROM %s WHERE i <= %s ORDER BY i",
+            "SELECT i, name FROM %s WHERE i <= %s",# ORDER BY i",
             sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="rows")]),
             rToTake
          )
          rowNames <- get_query(
             x, rquery, autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$i)
          
          cToTake <- max(values$j)
          cquery <- sprintf(
-            "SELECT j, name FROM %s WHERE j <= %s ORDER BY j",
+            "SELECT j, name FROM %s WHERE j <= %s",# ORDER BY j",
             sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="columns")]),
             cToTake
          )
          colNames <- get_query(
             x, cquery, autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$j)
          
          toRet <- Matrix::sparseMatrix(
             i=as.integer(values$i), j=as.integer(values$j), x=values$x,
@@ -2217,9 +2329,9 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
          if(dimcol=="___ROWNAMES___"){
             for(st in unique(chFields$table)){
                stquery <- sprintf(
-                  paste(query, 'ORDER BY %s'),
-                  sprintf('`%s`.`%s`', tdb, st),
-                  dimcol
+                  query,# paste(query, 'ORDER BY %s'),
+                  sprintf('`%s`.`%s`', tdb, st)#,
+                  # dimcol
                )
                stquery <- paste(
                   stquery,
@@ -2228,7 +2340,8 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
                stqr <- get_query(
                   x, stquery, autoalias=FALSE,
                   format="TabSeparatedWithNamesAndTypes"
-               )
+               ) %>% 
+                  dplyr::arrange(.data[[dimcol]])
                dimname <- stqr[[dimcol]]
                stopifnot(
                   !any(duplicated(dimname)),
@@ -2249,10 +2362,10 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
                return(NULL)
             }
             chFields <- chFields[(skip + 1):nrow(chFields),]
-            chFields <- chFields[1:min(nrow(chFields), n_max),]
+            chFields <- chFields[1:min(nrow(chFields), as.numeric(n_max)),]
             for(st in unique(chFields$table)){
                stquery <- sprintf(
-                  'SELECT `%s` FROM %s ORDER BY %s',
+                  'SELECT `%s` FROM %s",# ORDER BY %s',
                   paste(
                      c(
                         dimcol,
@@ -2260,13 +2373,14 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
                      ),
                      collapse='`, `'
                   ),
-                  sprintf('`%s`.`%s`', tdb, st),
-                  dimcol
+                  sprintf('`%s`.`%s`', tdb, st)#,
+                  # dimcol
                )
                stqr <- get_query(
                   x, stquery, autoalias=FALSE,
                   format="TabSeparatedWithNamesAndTypes"
-               )
+               ) %>% 
+                  dplyr::arrange(.data[[dimcol]])
                dimname <- stqr[[dimcol]]
                stopifnot(
                   !any(duplicated(dimname)),
@@ -2285,7 +2399,7 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
             toRet <- toRet[sort(rownames(toRet)),]
          }
       }
-   }else{{
+   }else{
       
       ## Table ----
       
@@ -2316,126 +2430,10 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
                dplyr::pull("type")
          )
       }
-   }}
+   }
    return(toRet)
 }
 
-.dim_ch_mtable <- function(x, tablePath, tableModel){
-   
-   tp <- gsub("`", "", strsplit(tablePath, split="`[.]`")[[1]])
-   tdb <- tp[1]
-   tn <- tp[2]
-   chTables <- list_tables(
-      unclass(x)$tkcon$chcon, dbNames=tdb
-   )
-   chFields <- get_query(
-      x,
-      sprintf(
-         paste(
-            "SELECT database, table, name FROM system.columns",
-            " WHERE database='%s'"
-         ),
-         tdb
-      ),
-      autoalias=FALSE,
-      format="TabSeparatedWithNamesAndTypes"
-   )
-   
-   if(ReDaMoR::is.MatrixModel(tableModel)){
-      dbmt <- tablePath
-      query <- "SELECT * FROM %s"
-      tquery <- sprintf(query, dbmt)
-      qr <- get_query(
-         x, tquery, autoalias=FALSE,
-         format="TabSeparatedWithNamesAndTypes"
-      )
-      
-      if(.is_chMM(qr)){
-         
-         ## Sparse matrix ----
-         
-         nr <- chTables %>% 
-            dplyr::filter(
-               .data$database==tdb &
-                  .data$name==qr$table[which(qr$info=="rows")]
-            ) %>% 
-            dplyr::pull("total_rows")
-         nc <- chTables %>% 
-            dplyr::filter(
-               .data$database==tdb &
-                  .data$name==qr$table[which(qr$info=="columns")]
-            ) %>% 
-            dplyr::pull("total_rows")
-         toRet <- dplyr::tibble(
-            format="MatrixMarket",
-            ncol=nc,
-            nrow=nr,
-            records=as.numeric(nc) * as.numeric(nr),
-            transposed=FALSE
-         )
-         
-      }else{
-         
-         ## Matrix ----
-      
-         nr <- chTables %>% 
-            dplyr::filter(
-               .data$database==tdb & .data$name==qr$table[1]
-            ) %>% 
-            dplyr::pull("total_rows")
-         tfields <- chFields %>% 
-            dplyr::filter(
-               .data$database==tdb,
-               .data$table %in% qr$table
-            )
-         if("___ROWNAMES___" %in% tfields$name){
-            if("___COLNAMES___" %in% tfields$name){
-               stop(paste0(tn, ": Ambiguous matrix format"))
-            }else{
-               transposed=FALSE
-            }
-         }else{
-            if("___COLNAMES___" %in% tfields$name){
-               transposed=TRUE
-            }else{
-               stop(paste0(tn, ": Wrong matrix format"))
-            }
-         }
-         nc <- nrow(tfields) - nrow(qr)
-         
-         toRet <- dplyr::tibble(
-            format="matrix",
-            ncol=ifelse(transposed, nr, nc),
-            nrow=ifelse(transposed, nc, nr),
-            records=as.numeric(nc) * as.numeric(nr),
-            transposed=transposed
-         )
-      
-      }
-      
-   }else{{
-      
-      ## Table ----
-      
-      toRet <- dplyr::tibble(
-         format="table",
-         ncol=length(tableModel),
-         nrow=dplyr::filter(
-            chTables,
-            .data$database==tdb,
-            .data$name==tn
-         ) %>% dplyr::pull("total_rows")
-      ) %>%
-         dplyr::mutate(
-            records=.data$nrow,
-            transposed=FALSE
-         )
-   }}
-   
-   return(toRet)
-
-}
-
 .head_ch_mtable <- function(
    x,
    tablePath,
@@ -2443,7 +2441,7 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
    n=6L
 ){
    if(ReDaMoR::is.MatrixModel(tableModel)){
-      dd <- .dim_ch_mtable(x, tablePath, tableModel)
+      dd <- dims(x, tableModel$tableName)
       
       if(is.infinite(n)){
          nc <- dd$ncol
@@ -2480,14 +2478,15 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
          ## Sparse matrix ----
          
          vquery <- sprintf(
-            "SELECT i, j, x FROM %s WHERE i <= %s AND j <= %s ORDER BY j, i",
+            "SELECT i, j, x FROM %s WHERE i <= %s AND j <= %s",# ORDER BY j, i",
             sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="values")]),
             nr, nc
          )
          values <- get_query(
             x, vquery, autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$j, .data$i)
          ## Sparse ==> all values may be missing
          if(nrow(values)==0){
             values <- dplyr::tibble(
@@ -2498,24 +2497,26 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
          }
 
          rquery <- sprintf(
-            "SELECT i, name FROM %s WHERE i <= %s ORDER BY i",
+            "SELECT i, name FROM %s WHERE i <= %s",# ORDER BY i",
             sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="rows")]),
             nr
          )
          rowNames <- get_query(
             x, rquery, autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$i)
          
          cquery <- sprintf(
-            "SELECT j, name FROM %s WHERE j <= %s ORDER BY j",
+            "SELECT j, name FROM %s WHERE j <= %s",# ORDER BY j",
             sprintf('`%s`.`%s`', tdb, qr$table[which(qr$info=="columns")]),
             nc
          )
          colNames <- get_query(
             x, cquery, autoalias=FALSE,
             format="Arrow"
-         )
+         ) %>% 
+            dplyr::arrange(.data$j)
          
          mi <- max(rowNames$i)
          mj <- max(colNames$j)
@@ -2567,7 +2568,8 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
          toRet <- c()
          for(st in unique(chFields$table)){
             stquery <- sprintf(
-               'SELECT `%s` FROM %s ORDER BY %s LIMIT %s',
+               # 'SELECT `%s` FROM %s ORDER BY %s LIMIT %s',
+               'SELECT `%s` FROM %s LIMIT %s',
                paste(
                   c(
                      dimcol,
@@ -2576,13 +2578,14 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
                   collapse='`, `'
                ),
                sprintf('`%s`.`%s`', tdb, st),
-               dimcol,
+               # dimcol,
                lim
             )
             stqr <- get_query(
                x, stquery, autoalias=FALSE,
                format="TabSeparatedWithNamesAndTypes"
-            )
+            ) %>% 
+               dplyr::arrange(.data[[dimcol]])
             dimname <- stqr[[dimcol]]
             stopifnot(
                !any(duplicated(dimname)),
@@ -2605,12 +2608,12 @@ filter_mdb_matrix.chMDB <- function(x, tableName, ...){
       
       }
       
-   }else{{
+   }else{
       ## Table ----
       return(.get_ch_mtable(
          x, tablePath=tablePath, tableModel=tableModel, n_max=n
       ))
-   }}
+   }
 }
 
 .ch_filtByConta <- function(d, fdb, fk, by=10^5){
